#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-fileio
version:              0.3.16.7
visibility:           public
id:                   system-fileio-0.3.16.7-2mtmbi78ydWBRedor0kPwe
key:                  system-fileio-0.3.16.7-2mtmbi78ydWBRedor0kPwe
license:              MIT
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Consistent filesystem interaction across GHC versions (deprecated package).

category:             System
abi:                  64c8902273c6c8fa02facda3a0b5940a
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/system-fileio-0.3.16.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-fileio
hs-libraries:         HSsystem-fileio-0.3.16.7-2mtmbi78ydWBRedor0kPwe
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    system-filepath-0.4.14.1-An7R1etXWpHFxlmWbsr4t5 text-2.0.2
    time-1.12.2 unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

